California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: 2003 RECALL QUESTION View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257926 | CALIFORNIANS FOR GOVERNMENT ACCOUNTABILITY - NO ON THE GOVERNOR'S RECALL - YES ON BUSTAMANTE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256416 | CALIFORNIANS AGAINST THE COSTLY RECALL OF THE GOVERNOR: COALITION OF FIREFIGHTERS, WORKERS, EDUCATORS, BUS, BUS LEADERS, CA DEM PARTY, ENTERTAINMENT BUS, DEM GOVERNORS, GOVERNOR GRAY DAVIS COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258540 | MOVEON.ORG PAC A COMMITTEE AGAINST THE RECALL OF THE GOVERNOR AND PROPOSITION 54 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991523 | RECALL DAVIS COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1253179 | RECALL GRAY DAVIS COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1253300 | DAVIS RECALL COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254571 | RECALL GRAY DAVIS NOW | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254759 | RESCUE CALIFORNIA...RECALL GRAY DAVIS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254858 | RECALL GRAY DAVIS TODAY COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1255059 | TAXPAYERS AGAINST THE GOVERNOR'S RECALL, ENVIRONMENTAL, LABOR AND RELIGIOUS ORGANIZATIONS AND OTHERS WHO OPPOSE THE WASTE OF TAXPAYER DOLLARS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256375 | DEMOCRATS AGAINST GRAY DAVIS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1255584 | DAVIS, REPUBLICANS AGAINST THE RECALL. COM, AGAINST THE RECALL OF GOVERNOR | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257330 | SCHWARZENEGGER'S TOTAL RECALL COMMITTEE, VOTE YES TO RECALL GRAY DAVIS, ARNOLD | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257244 | CALIFORNIANS FOR STABILITY - NO ON THE GOVERNOR'S RECALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257589 | ALAMEDA COUNTY AGAINST THE RECALL DBA ACAR | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258109 | SACRAMENTO COUNTY DEMOCRATS OPPOSED TO THE RECALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
962636 | DAVIS COMMITTEE, THE GOVERNOR GRAY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256989 | PROGRESSIVE DEMOCRATS AND INDEPENDENTS AGAINST THE GOVERNOR'S RECALL | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256875 | CALIFORNIANS TO STOP THE CON! NO ON THE RECALL & NO ON PROP. 54 (SPONSORED BY NEIGHBOR TO NEIGHBOR) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257701 | CALIFORNIA MAJORITY | OPPOSE